@@ -112,6 +112,8 @@ tune_race_anova.recipe <- function(object, model, resamples, ..., param_info = N
                                    control = control_race()) {
   tune::empty_ellipses(...)
 
+  control <- parsnip::condense_control(control, control_race())
+
   tune_race_anova(
     model,
     preprocessor = object, resamples = resamples,
@@ -126,6 +128,8 @@ tune_race_anova.formula <- function(formula, model, resamples, ..., param_info =
                                     control = control_race()) {
   tune::empty_ellipses(...)
 
+  control <- parsnip::condense_control(control, control_race())
+
   tune_race_anova(
     model,
     preprocessor = formula, resamples = resamples,
@@ -148,6 +152,8 @@ tune_race_anova.model_spec <- function(object, preprocessor, resamples, ...,
 
   tune::empty_ellipses(...)
 
+  control <- parsnip::condense_control(control, control_race())
+
   wflow <- workflows::add_model(workflows::workflow(), object)
 
   if (tune::is_recipe(preprocessor)) {
@@ -173,6 +179,8 @@ tune_race_anova.workflow <- function(object, resamples, ..., param_info = NULL,
                                      control = control_race()) {
   tune::empty_ellipses(...)
 
+  control <- parsnip::condense_control(control, control_race())
+
   tune_race_anova_workflow(
     object,
     resamples = resamples,
@@ -202,6 +210,7 @@ tune_race_anova_workflow <-
 
     control$pkgs <- c(tune::required_pkgs(object), "workflows", "tidyr", "rlang")
 
+    grid_control <- parsnip::condense_control(control, tune::control_grid())
     res <-
       object %>%
       tune::tune_grid(
@@ -209,7 +218,7 @@ tune_race_anova_workflow <-
         param_info = param_info,
         grid = grid,
         metrics = metrics,
-        control = control
+        control = grid_control
       )
 
     param_names <- tune::.get_tune_parameter_names(res)
@@ -256,6 +265,7 @@ tune_race_anova_workflow <-
         log_final <- FALSE
       }
 
+      grid_control <- parsnip::condense_control(control, tune::control_grid())
       tmp_res <-
         object %>%
         tune::tune_grid(
@@ -263,7 +273,7 @@ tune_race_anova_workflow <-
           param_info = param_info,
           grid = new_grid,
           metrics = metrics,
-          control = control
+          control = grid_control
         )
 
       res <- restore_tune(res, tmp_res)
